[![Build Status](https://img.shields.io/travis/loopmediagroup/py-gardener/master.svg)](https://travis-ci.org/loopmediagroup/py-gardener)
[![Coverage Status](https://coveralls.io/repos/github/loopmediagroup/py-gardener/badge.svg?branch=master)](https://coveralls.io/github/loopmediagroup/py-gardener?branch=master)
[![Dependencies](https://pyup.io/repos/github/loopmediagroup/py-gardener/shield.svg?t=1518818417448)](https://pyup.io)

# Py-Gardener

Released on [pypi](https://pypi.python.org/pypi/Py-Gardener). Install with

`pip install py-gardener`

### What is Py-Gardener?

Py-Gardener enforces best practices for your python project.

### Run Tests

Check out [SETUP.md](SETUP.md)

### Where can I get help?

Please open a github issue.

-------------------

## Getting Started

....

## What are the tests?

....